ActionIrV1

Struct ActionIrV1 

pub struct ActionIrV1 {
    pub schema_version: u32,
    pub operation_id: String,
    pub actions: Vec<DeclarativeActionV1>,
}

Fields

schema_version: u32operation_id: Stringactions: Vec<DeclarativeActionV1>

Implementations

Source

impl ActionIrV1

pub fn new( operation_id: impl Into<String>, actions: Vec<DeclarativeActionV1>, ) -> Self

pub fn validate(&self) -> Result<(), ActionIrError>

pub fn permission_requirements( &self, path_identity: impl Fn(&Path) -> String, ) -> ActionPermissionRequirementsV1

Derive the exact filesystem capabilities required by the executable actions. Infrastructure permissions for journal persistence are added by the runtime planner, not hidden inside this derivation.