pub struct AppEntry {
pub source: String,
pub destination: PathBuf,
pub backup: Option<PathBuf>,
pub content_hash: u64,
pub install_strategy: AppInstallStrategy,
pub uses_env: bool,
pub requires_admin: bool,
}Fields
source: Stringdestination: PathBufbackup: Option<PathBuf>content_hash: u64install_strategy: AppInstallStrategyuses_env: boolTrue when the template transform was applied during install.
Used by config upgrade to skip files that never used env vars.
requires_admin: boolTrue when installing/removing this file requires elevated (sudo) permissions.